@@ -583,6 +583,11 @@ bool KFilePlacesModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         KBookmark bookmark = item->bookmark();
 
         int destRow = row == -1 ? d->items.count() : row;
+        // The item is not moved when the drop indicator is on either item edge
+        if (itemRow == destRow || itemRow + 1 == destRow) {
+            return false;
+        }
+
         beginMoveRows(QModelIndex(), itemRow, itemRow, QModelIndex(), destRow);
         d->bookmarkManager->root().moveBookmark(bookmark, afterBookmark);
         // Move item ourselves so that _k_reloadBookmarks() does not consider
@@ -627,6 +632,8 @@ bool KFilePlacesModel::dropMimeData(const QMimeData *data, Qt::DropAction action
         return false;
     }
 
+    d->sharedBookmarks->updateSharedBookmarks();
+
     d->reloadAndSignal();
 
     return true;
@@ -654,6 +661,8 @@ void KFilePlacesModel::addPlace(const QString &text, const KUrl &url,
         d->bookmarkManager->root().moveBookmark(bookmark, item->bookmark());
     }
 
+    d->sharedBookmarks->updateSharedBookmarks();
+
     d->reloadAndSignal();
 }
 
@@ -675,6 +684,8 @@ void KFilePlacesModel::editPlace(const QModelIndex &index, const QString &text,
     bookmark.setIcon(iconName);
     bookmark.setMetaDataItem("OnlyInApp", appName);
 
+    d->sharedBookmarks->updateSharedBookmarks();
+
     d->reloadAndSignal();
     emit dataChanged(index, index);
 }
@@ -692,6 +703,7 @@ void KFilePlacesModel::removePlace(const QModelIndex &index) const
     if (bookmark.isNull()) return;
 
     d->bookmarkManager->root().deleteBookmark(bookmark);
+    d->sharedBookmarks->updateSharedBookmarks();
     d->reloadAndSignal();
 }
 
@@ -707,6 +719,8 @@ void KFilePlacesModel::setPlaceHidden(const QModelIndex &index, bool hidden)
 
     bookmark.setMetaDataItem("IsHidden", (hidden ? "true" : "false"));
 
+    d->sharedBookmarks->updateSharedBookmarks();
+
     d->reloadAndSignal();
     emit dataChanged(index, index);
 }
